<template>
  <div class="my-collect-task">
    <div class="my-collect-task-title">收藏任务列表</div>
    <div class="my-collect-task-btn">清空已失效任务</div>
  </div>
  <InfiniteLoading
    scrollViewClassName="common-infinite-scroll-list home-list"
    v-bind="infiniteLoadingProps"
  >
    <template #renderItem="{ item }">
      <TaskCard> </TaskCard>
    </template>
  </InfiniteLoading>
</template>

<script setup lang="ts">
import { TaskCard } from '@12333/components';
import { useUserStore } from '@/stores/modules/user';
import { useInfiniteLoading } from '@12333/hooks';
import { OrderInputType } from '@12333/constants';
import * as flexWorkerServices from '@12333/services/api/FlexWorker';

defineOptions({
  name: 'InnerPage',
});

const userStore = useUserStore();

const { infiniteLoadingProps } = useInfiniteLoading(
  ({ pageParam }) => {
    let params: API.GetFlexTaskListInput = {
      pageModel: {
        rows: 20,
        page: pageParam,
        orderInput: [{ property: 'creationTime', order: OrderInputType.Desc }],
      },
    };

    return flexWorkerServices.getFlexTaskByArrange(params, {
      showLoading: false,
    });
  },
  {
    queryKey: ['flexWorkerServices/getFlexTaskByArrange'],
  }
);
</script>

<style lang="scss">
@import '@/styles/common.scss';

.mineCollectTask-page-wrapper {
  .my-collect-task {
    display: flex;
    align-items: center;
    justify-content: space-between;
    padding: 30px 40px;

    .my-collect-task-title {
      font-size: 28px;
      line-height: 40px;
      color: boleGetCssVar('text-color', 'primary');
    }

    .my-collect-task-btn {
      font-size: 24px;
      line-height: 34px;
      color: boleGetCssVar('text-color', 'regular');
    }
  }
}
</style>
